Struct AsyncTask

pub struct AsyncTask<T>
where T: NotResult,
{ /* private fields */ }
Generic async task wrapper for single operations

This wraps a oneshot::Receiver and implements Future to provide a concrete return type instead of boxed futures or async fn.

IMPORTANT: AsyncTask must never return Result types - all error handling should be done internally before creating the AsyncTask.

Implementations

Source

impl<T> AsyncTask<T>
where T: NotResult,

pub fn new(receivers: ZeroOneOrMany<Receiver<T>>) -> Self
where T: Send + 'static,

Create a new AsyncTask from ZeroOneOrMany receivers

pub fn from_future<F>(future: F) -> Self
where F: Future<Output = T> + Send + 'static, T: Send + 'static,

Create an AsyncTask from a future

pub fn from_value(value: T) -> Self
where T: Send + 'static,

Create an AsyncTask from a value

pub fn spawn<F>(f: F) -> Self
where F: FnOnce() -> T + Send + 'static, T: Send + 'static,

Create an AsyncTask that spawns a blocking task