pub struct AsyncTask<T>where
T: NotResult,{ /* private fields */ }Expand description
Generic async task wrapper for single operations
This wraps a oneshot::Receiver and implements Future to provide a concrete return type instead of boxed futures or async fn.
IMPORTANT: AsyncTask must never return Result types - all error handling should be done internally before creating the AsyncTask.
Implementations
Sourceimpl<T> AsyncTask<T>where
T: NotResult,
impl<T> AsyncTask<T>where
T: NotResult,
Sourcepub fn new(receivers: ZeroOneOrMany<Receiver<T>>) -> Selfwhere
T: Send + 'static,
pub fn new(receivers: ZeroOneOrMany<Receiver<T>>) -> Selfwhere
T: Send + 'static,
Create a new AsyncTask from ZeroOneOrMany receivers
Sourcepub fn from_future<F>(future: F) -> Self
pub fn from_future<F>(future: F) -> Self
Create an AsyncTask from a future
Sourcepub fn from_value(value: T) -> Selfwhere
T: Send + 'static,
pub fn from_value(value: T) -> Selfwhere
T: Send + 'static,
Create an AsyncTask from a value